# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/mint/v1beta1/mint.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/mint/v1beta1/mint.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x63osmos/mint/v1beta1/mint.proto\x12\x13\x63osmos.mint.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x11\x61mino/amino.proto\"\x9c\x01\n\x06Minter\x12\x44\n\tinflation\x18\x01 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\x12L\n\x11\x61nnual_provisions\x18\x02 \x01(\tB1\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\"\x96\x03\n\x06Params\x12\x12\n\nmint_denom\x18\x01 \x01(\t\x12U\n\x15inflation_rate_change\x18\x02 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12M\n\rinflation_max\x18\x03 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12M\n\rinflation_min\x18\x04 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12K\n\x0bgoal_bonded\x18\x05 \x01(\tB6\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDec\xd2\xb4-\ncosmos.Dec\xa8\xe7\xb0*\x01\x12\x17\n\x0f\x62locks_per_year\x18\x06 \x01(\x04:\x1d\x8a\xe7\xb0*\x18\x63osmos-sdk/x/mint/ParamsB+Z)github.com/cosmos/cosmos-sdk/x/mint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.mint.v1beta1.mint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/x/mint/types'
  _globals['_MINTER'].fields_by_name['inflation']._loaded_options = None
  _globals['_MINTER'].fields_by_name['inflation']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_MINTER'].fields_by_name['annual_provisions']._loaded_options = None
  _globals['_MINTER'].fields_by_name['annual_provisions']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec'
  _globals['_PARAMS'].fields_by_name['inflation_rate_change']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['inflation_rate_change']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['inflation_max']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['inflation_max']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['inflation_min']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['inflation_min']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS'].fields_by_name['goal_bonded']._loaded_options = None
  _globals['_PARAMS'].fields_by_name['goal_bonded']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec\322\264-\ncosmos.Dec\250\347\260*\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\212\347\260*\030cosmos-sdk/x/mint/Params'
  _globals['_MINTER']._serialized_start=124
  _globals['_MINTER']._serialized_end=280
  _globals['_PARAMS']._serialized_start=283
  _globals['_PARAMS']._serialized_end=689
# @@protoc_insertion_point(module_scope)



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("max_metadata_len", "authority")
    MAX_METADATA_LEN_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    max_metadata_len: int
    authority: str
    def __init__(self, max_metadata_len: _Optional[int] = ..., authority: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/clob/liquidations_config.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/clob/liquidations_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dydxprotocol/clob/liquidations_config.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\"\xa0\x02\n\x12LiquidationsConfig\x12\x1f\n\x17max_liquidation_fee_ppm\x18\x01 \x01(\r\x12K\n\x15position_block_limits\x18\x02 \x01(\x0b\x32&.dydxprotocol.clob.PositionBlockLimitsB\x04\xc8\xde\x1f\x00\x12O\n\x17subaccount_block_limits\x18\x03 \x01(\x0b\x32(.dydxprotocol.clob.SubaccountBlockLimitsB\x04\xc8\xde\x1f\x00\x12K\n\x15\x66illable_price_config\x18\x04 \x01(\x0b\x32&.dydxprotocol.clob.FillablePriceConfigB\x04\xc8\xde\x1f\x00\"l\n\x13PositionBlockLimits\x12(\n min_position_notional_liquidated\x18\x01 \x01(\x04\x12+\n#max_position_portion_liquidated_ppm\x18\x02 \x01(\r\"]\n\x15SubaccountBlockLimits\x12\x1f\n\x17max_notional_liquidated\x18\x01 \x01(\x04\x12#\n\x1bmax_quantums_insurance_lost\x18\x02 \x01(\x04\"h\n\x13\x46illablePriceConfig\x12!\n\x19\x62\x61nkruptcy_adjustment_ppm\x18\x01 \x01(\r\x12.\n&spread_to_maintenance_margin_ratio_ppm\x18\x02 \x01(\rB8Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.liquidations_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['position_block_limits']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['position_block_limits']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['subaccount_block_limits']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['subaccount_block_limits']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['fillable_price_config']._loaded_options = None
  _globals['_LIQUIDATIONSCONFIG'].fields_by_name['fillable_price_config']._serialized_options = b'\310\336\037\000'
  _globals['_LIQUIDATIONSCONFIG']._serialized_start=89
  _globals['_LIQUIDATIONSCONFIG']._serialized_end=377
  _globals['_POSITIONBLOCKLIMITS']._serialized_start=379
  _globals['_POSITIONBLOCKLIMITS']._serialized_end=487
  _globals['_SUBACCOUNTBLOCKLIMITS']._serialized_start=489
  _globals['_SUBACCOUNTBLOCKLIMITS']._serialized_end=582
  _globals['_FILLABLEPRICECONFIG']._serialized_start=584
  _globals['_FILLABLEPRICECONFIG']._serialized_end=688
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/sending/genesis.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/sending/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"dydxprotocol/sending/genesis.proto\x12\x14\x64ydxprotocol.sending\"\x0e\n\x0cGenesisStateB;Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.sending.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z9github.com/dydxprotocol/v4-chain/protocol/x/sending/types'
  _globals['_GENESISSTATE']._serialized_start=60
  _globals['_GENESISSTATE']._serialized_end=74
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tendermint/types/validator.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'tendermint/types/validator.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.tendermint.crypto import keys_pb2 as tendermint_dot_crypto_dot_keys__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/types/validator.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1ctendermint/crypto/keys.proto\"\x8a\x01\n\x0cValidatorSet\x12/\n\nvalidators\x18\x01 \x03(\x0b\x32\x1b.tendermint.types.Validator\x12-\n\x08proposer\x18\x02 \x01(\x0b\x32\x1b.tendermint.types.Validator\x12\x1a\n\x12total_voting_power\x18\x03 \x01(\x03\"\x82\x01\n\tValidator\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x33\n\x07pub_key\x18\x02 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKeyB\x04\xc8\xde\x1f\x00\x12\x14\n\x0cvoting_power\x18\x03 \x01(\x03\x12\x19\n\x11proposer_priority\x18\x04 \x01(\x03\"V\n\x0fSimpleValidator\x12-\n\x07pub_key\x18\x01 \x01(\x0b\x32\x1c.tendermint.crypto.PublicKey\x12\x14\n\x0cvoting_power\x18\x02 \x01(\x03*\xd7\x01\n\x0b\x42lockIDFlag\x12\x31\n\x15\x42LOCK_ID_FLAG_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x42lockIDFlagUnknown\x12/\n\x14\x42LOCK_ID_FLAG_ABSENT\x10\x01\x1a\x15\x8a\x9d \x11\x42lockIDFlagAbsent\x12/\n\x14\x42LOCK_ID_FLAG_COMMIT\x10\x02\x1a\x15\x8a\x9d \x11\x42lockIDFlagCommit\x12)\n\x11\x42LOCK_ID_FLAG_NIL\x10\x03\x1a\x12\x8a\x9d \x0e\x42lockIDFlagNil\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x01\x42\x35Z3github.com/cometbft/cometbft/proto/tendermint/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.validator_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z3github.com/cometbft/cometbft/proto/tendermint/types'
  _globals['_BLOCKIDFLAG']._loaded_options = None
  _globals['_BLOCKIDFLAG']._serialized_options = b'\210\243\036\000\250\244\036\001'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_UNKNOWN"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_UNKNOWN"]._serialized_options = b'\212\235 \022BlockIDFlagUnknown'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_ABSENT"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_ABSENT"]._serialized_options = b'\212\235 \021BlockIDFlagAbsent'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_COMMIT"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_COMMIT"]._serialized_options = b'\212\235 \021BlockIDFlagCommit'
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_NIL"]._loaded_options = None
  _globals['_BLOCKIDFLAG'].values_by_name["BLOCK_ID_FLAG_NIL"]._serialized_options = b'\212\235 \016BlockIDFlagNil'
  _globals['_VALIDATOR'].fields_by_name['pub_key']._loaded_options = None
  _globals['_VALIDATOR'].fields_by_name['pub_key']._serialized_options = b'\310\336\037\000'
  _globals['_BLOCKIDFLAG']._serialized_start=469
  _globals['_BLOCKIDFLAG']._serialized_end=684
  _globals['_VALIDATORSET']._serialized_start=107
  _globals['_VALIDATORSET']._serialized_end=245
  _globals['_VALIDATOR']._serialized_start=248
  _globals['_VALIDATOR']._serialized_end=378
  _globals['_SIMPLEVALIDATOR']._serialized_start=380
  _globals['_SIMPLEVALIDATOR']._serialized_end=466
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.distribution.v1beta1 import tx_pb2 as cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.66.2'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/distribution/v1beta1/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the distribution Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SetWithdrawAddress = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/SetWithdrawAddress',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddress.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddressResponse.FromString,
                _registered_method=True)
        self.WithdrawDelegatorReward = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/WithdrawDelegatorReward',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorReward.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorRewardResponse.FromString,
                _registered_method=True)
        self.WithdrawValidatorCommission = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/WithdrawValidatorCommission',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommission.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommissionResponse.FromString,
                _registered_method=True)
        self.FundCommunityPool = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/FundCommunityPool',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPool.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPoolResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/UpdateParams',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.CommunityPoolSpend = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/CommunityPoolSpend',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpend.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpendResponse.FromString,
                _registered_method=True)
        self.DepositValidatorRewardsPool = channel.unary_unary(
                '/cosmos.distribution.v1beta1.Msg/DepositValidatorRewardsPool',
                request_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPool.SerializeToString,
                response_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPoolResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the distribution Msg service.
    """

    def SetWithdrawAddress(self, request, context):
        """SetWithdrawAddress defines a method to change the withdraw address
        for a delegator (or validator self-delegation).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawDelegatorReward(self, request, context):
        """WithdrawDelegatorReward defines a method to withdraw rewards of delegator
        from a single validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WithdrawValidatorCommission(self, request, context):
        """WithdrawValidatorCommission defines a method to withdraw the
        full commission to the validator address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FundCommunityPool(self, request, context):
        """FundCommunityPool defines a method to allow an account to directly
        fund the community pool.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/distribution
        module parameters. The authority is defined in the keeper.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CommunityPoolSpend(self, request, context):
        """CommunityPoolSpend defines a governance operation for sending tokens from
        the community pool in the x/distribution module to another account, which
        could be the governance module itself. The authority is defined in the
        keeper.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DepositValidatorRewardsPool(self, request, context):
        """DepositValidatorRewardsPool defines a method to provide additional rewards
        to delegators to a specific validator.

        Since: cosmos-sdk 0.50
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SetWithdrawAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWithdrawAddress,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddress.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddressResponse.SerializeToString,
            ),
            'WithdrawDelegatorReward': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawDelegatorReward,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorReward.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorRewardResponse.SerializeToString,
            ),
            'WithdrawValidatorCommission': grpc.unary_unary_rpc_method_handler(
                    servicer.WithdrawValidatorCommission,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommission.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommissionResponse.SerializeToString,
            ),
            'FundCommunityPool': grpc.unary_unary_rpc_method_handler(
                    servicer.FundCommunityPool,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPool.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPoolResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'CommunityPoolSpend': grpc.unary_unary_rpc_method_handler(
                    servicer.CommunityPoolSpend,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpend.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpendResponse.SerializeToString,
            ),
            'DepositValidatorRewardsPool': grpc.unary_unary_rpc_method_handler(
                    servicer.DepositValidatorRewardsPool,
                    request_deserializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPool.FromString,
                    response_serializer=cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPoolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.distribution.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.distribution.v1beta1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the distribution Msg service.
    """

    @staticmethod
    def SetWithdrawAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/SetWithdrawAddress',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddress.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgSetWithdrawAddressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawDelegatorReward(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/WithdrawDelegatorReward',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorReward.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawDelegatorRewardResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def WithdrawValidatorCommission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/WithdrawValidatorCommission',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommission.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgWithdrawValidatorCommissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FundCommunityPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/FundCommunityPool',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPool.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgFundCommunityPoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/UpdateParams',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CommunityPoolSpend(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/CommunityPoolSpend',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpend.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgCommunityPoolSpendResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DepositValidatorRewardsPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.distribution.v1beta1.Msg/DepositValidatorRewardsPool',
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPool.SerializeToString,
            cosmos_dot_distribution_dot_v1beta1_dot_tx__pb2.MsgDepositValidatorRewardsPoolResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("fee_collector_name", "authority")
    FEE_COLLECTOR_NAME_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    fee_collector_name: str
    authority: str
    def __init__(self, fee_collector_name: _Optional[str] = ..., authority: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vest/genesis.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/vest/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as dydxprotocol_dot_vest_dot_vest__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x64ydxprotocol/vest/genesis.proto\x12\x11\x64ydxprotocol.vest\x1a\x14gogoproto/gogo.proto\x1a\"dydxprotocol/vest/vest_entry.proto\"H\n\x0cGenesisState\x12\x38\n\x0cvest_entries\x18\x01 \x03(\x0b\x32\x1c.dydxprotocol.vest.VestEntryB\x04\xc8\xde\x1f\x00\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_GENESISSTATE'].fields_by_name['vest_entries']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['vest_entries']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=112
  _globals['_GENESISSTATE']._serialized_end=184
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/group/module/v1/module.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/group/module/v1/module.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.app.v1alpha1 import module_pb2 as cosmos_dot_app_dot_v1alpha1_dot_module__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/group/module/v1/module.proto\x12\x16\x63osmos.group.module.v1\x1a cosmos/app/v1alpha1/module.proto\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x11\x61mino/amino.proto\"\x98\x01\n\x06Module\x12\x46\n\x14max_execution_period\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\r\xc8\xde\x1f\x00\x98\xdf\x1f\x01\xa8\xe7\xb0*\x01\x12\x18\n\x10max_metadata_len\x18\x02 \x01(\x04:,\xba\xc0\x96\xda\x01&\n$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.module.v1.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULE'].fields_by_name['max_execution_period']._loaded_options = None
  _globals['_MODULE'].fields_by_name['max_execution_period']._serialized_options = b'\310\336\037\000\230\337\037\001\250\347\260*\001'
  _globals['_MODULE']._loaded_options = None
  _globals['_MODULE']._serialized_options = b'\272\300\226\332\001&\n$github.com/cosmos/cosmos-sdk/x/group'
  _globals['_MODULE']._serialized_start=171
  _globals['_MODULE']._serialized_end=323
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/consensus/v1/tx.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/consensus/v1/tx.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/consensus/v1/tx.proto\x12\x13\x63osmos.consensus.v1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1dtendermint/types/params.proto\"\xbd\x02\n\x0fMsgUpdateParams\x12+\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12,\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1d.tendermint.types.BlockParams\x12\x32\n\x08\x65vidence\x18\x03 \x01(\x0b\x32 .tendermint.types.EvidenceParams\x12\x34\n\tvalidator\x18\x04 \x01(\x0b\x32!.tendermint.types.ValidatorParams\x12*\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1c.tendermint.types.ABCIParams:9\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*&cosmos-sdk/x/consensus/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2p\n\x03Msg\x12\x62\n\x0cUpdateParams\x12$.cosmos.consensus.v1.MsgUpdateParams\x1a,.cosmos.consensus.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x30Z.github.com/cosmos/cosmos-sdk/x/consensus/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/cosmos/cosmos-sdk/x/consensus/types'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*&cosmos-sdk/x/consensus/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=156
  _globals['_MSGUPDATEPARAMS']._serialized_end=473
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=475
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=500
  _globals['_MSG']._serialized_start=502
  _globals['_MSG']._serialized_end=614
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: dydxprotocol/vault/genesis.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'dydxprotocol/vault/genesis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.vault import params_pb2 as dydxprotocol_dot_vault_dot_params__pb2
from v4_proto.dydxprotocol.vault import share_pb2 as dydxprotocol_dot_vault_dot_share__pb2
from v4_proto.dydxprotocol.vault import vault_pb2 as dydxprotocol_dot_vault_dot_vault__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n dydxprotocol/vault/genesis.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\x1a\x1f\x64ydxprotocol/vault/params.proto\x1a\x1e\x64ydxprotocol/vault/share.proto\x1a\x1e\x64ydxprotocol/vault/vault.proto\"\x90\x03\n\x0cGenesisState\x12\x39\n\x0ctotal_shares\x18\x01 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumSharesB\x04\xc8\xde\x1f\x00\x12:\n\x0cowner_shares\x18\x02 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShareB\x04\xc8\xde\x1f\x00\x12/\n\x06vaults\x18\x03 \x03(\x0b\x32\x19.dydxprotocol.vault.VaultB\x04\xc8\xde\x1f\x00\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x04 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00\x12L\n\x17\x61ll_owner_share_unlocks\x18\x05 \x03(\x0b\x32%.dydxprotocol.vault.OwnerShareUnlocksB\x04\xc8\xde\x1f\x00\x12\x41\n\x0foperator_params\x18\x06 \x01(\x0b\x32\".dydxprotocol.vault.OperatorParamsB\x04\xc8\xde\x1f\x00\"\x99\x01\n\x05Vault\x12\x33\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultIdB\x04\xc8\xde\x1f\x00\x12;\n\x0cvault_params\x18\x02 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x03 \x03(\r\"\x8a\x01\n\x0eGenesisStateV6\x12)\n\x06vaults\x18\x02 \x03(\x0b\x32\x19.dydxprotocol.vault.Vault\x12G\n\x16\x64\x65\x66\x61ult_quoting_params\x18\x03 \x01(\x0b\x32!.dydxprotocol.vault.QuotingParamsB\x04\xc8\xde\x1f\x00J\x04\x08\x01\x10\x02\"\x80\x02\n\x07VaultV6\x12-\n\x08vault_id\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.vault.VaultId\x12\x33\n\x0ctotal_shares\x18\x02 \x01(\x0b\x32\x1d.dydxprotocol.vault.NumShares\x12\x34\n\x0cowner_shares\x18\x03 \x03(\x0b\x32\x1e.dydxprotocol.vault.OwnerShare\x12;\n\x0cvault_params\x18\x04 \x01(\x0b\x32\x1f.dydxprotocol.vault.VaultParamsB\x04\xc8\xde\x1f\x00\x12\x1e\n\x16most_recent_client_ids\x18\x05 \x03(\rB9Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_GENESISSTATE'].fields_by_name['total_shares']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['total_shares']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['owner_shares']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['owner_shares']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['vaults']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['vaults']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['all_owner_share_unlocks']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['all_owner_share_unlocks']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['operator_params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['operator_params']._serialized_options = b'\310\336\037\000'
  _globals['_VAULT'].fields_by_name['vault_id']._loaded_options = None
  _globals['_VAULT'].fields_by_name['vault_id']._serialized_options = b'\310\336\037\000'
  _globals['_VAULT'].fields_by_name['vault_params']._loaded_options = None
  _globals['_VAULT'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATEV6'].fields_by_name['default_quoting_params']._loaded_options = None
  _globals['_GENESISSTATEV6'].fields_by_name['default_quoting_params']._serialized_options = b'\310\336\037\000'
  _globals['_VAULTV6'].fields_by_name['vault_params']._loaded_options = None
  _globals['_VAULTV6'].fields_by_name['vault_params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE']._serialized_start=176
  _globals['_GENESISSTATE']._serialized_end=576
  _globals['_VAULT']._serialized_start=579
  _globals['_VAULT']._serialized_end=732
  _globals['_GENESISSTATEV6']._serialized_start=735
  _globals['_GENESISSTATEV6']._serialized_end=873
  _globals['_VAULTV6']._serialized_start=876
  _globals['_VAULTV6']._serialized_end=1132
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.gov.v1 import tx_pb2 as cosmos_dot_gov_dot_v1_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.66.2'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/gov/v1/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class MsgStub(object):
    """Msg defines the gov Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SubmitProposal = channel.unary_unary(
                '/cosmos.gov.v1.Msg/SubmitProposal',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
                _registered_method=True)
        self.ExecLegacyContent = channel.unary_unary(
                '/cosmos.gov.v1.Msg/ExecLegacyContent',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContent.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContentResponse.FromString,
                _registered_method=True)
        self.Vote = channel.unary_unary(
                '/cosmos.gov.v1.Msg/Vote',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVote.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteResponse.FromString,
                _registered_method=True)
        self.VoteWeighted = channel.unary_unary(
                '/cosmos.gov.v1.Msg/VoteWeighted',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeighted.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeightedResponse.FromString,
                _registered_method=True)
        self.Deposit = channel.unary_unary(
                '/cosmos.gov.v1.Msg/Deposit',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDeposit.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDepositResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/cosmos.gov.v1.Msg/UpdateParams',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)
        self.CancelProposal = channel.unary_unary(
                '/cosmos.gov.v1.Msg/CancelProposal',
                request_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposal.SerializeToString,
                response_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposalResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the gov Msg service.
    """

    def SubmitProposal(self, request, context):
        """SubmitProposal defines a method to create new proposal given the messages.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecLegacyContent(self, request, context):
        """ExecLegacyContent defines a Msg to be in included in a MsgSubmitProposal
        to execute a legacy content-based proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Vote(self, request, context):
        """Vote defines a method to add a vote on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VoteWeighted(self, request, context):
        """VoteWeighted defines a method to add a weighted vote on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deposit(self, request, context):
        """Deposit defines a method to add deposit on a specific proposal.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines a governance operation for updating the x/gov module
        parameters. The authority is defined in the keeper.

        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelProposal(self, request, context):
        """CancelProposal defines a method to cancel governance proposal

        Since: cosmos-sdk 0.50
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SubmitProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitProposal,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposal.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.SerializeToString,
            ),
            'ExecLegacyContent': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecLegacyContent,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContent.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContentResponse.SerializeToString,
            ),
            'Vote': grpc.unary_unary_rpc_method_handler(
                    servicer.Vote,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVote.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteResponse.SerializeToString,
            ),
            'VoteWeighted': grpc.unary_unary_rpc_method_handler(
                    servicer.VoteWeighted,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeighted.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeightedResponse.SerializeToString,
            ),
            'Deposit': grpc.unary_unary_rpc_method_handler(
                    servicer.Deposit,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDeposit.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDepositResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
            'CancelProposal': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelProposal,
                    request_deserializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposal.FromString,
                    response_serializer=cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposalResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.gov.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.gov.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the gov Msg service.
    """

    @staticmethod
    def SubmitProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/SubmitProposal',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposal.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgSubmitProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExecLegacyContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/ExecLegacyContent',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContent.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgExecLegacyContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Vote(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/Vote',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVote.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VoteWeighted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/VoteWeighted',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeighted.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgVoteWeightedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Deposit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/Deposit',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDeposit.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgDepositResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/UpdateParams',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelProposal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.gov.v1.Msg/CancelProposal',
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposal.SerializeToString,
            cosmos_dot_gov_dot_v1_dot_tx__pb2.MsgCancelProposalResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/staking/v1beta1/query.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/staking/v1beta1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.staking.v1beta1 import staking_pb2 as cosmos_dot_staking_dot_v1beta1_dot_staking__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from v4_proto.cosmos.query.v1 import query_pb2 as cosmos_dot_query_dot_v1_dot_query__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/staking/v1beta1/query.proto\x12\x16\x63osmos.staking.v1beta1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/staking/v1beta1/staking.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1b\x63osmos/query/v1/query.proto\x1a\x11\x61mino/amino.proto\"d\n\x16QueryValidatorsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\x98\x01\n\x17QueryValidatorsResponse\x12@\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"R\n\x15QueryValidatorRequest\x12\x39\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\"Y\n\x16QueryValidatorResponse\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x99\x01\n QueryValidatorDelegationsRequest\x12\x39\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xcc\x01\n!QueryValidatorDelegationsResponse\x12j\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB \xc8\xde\x1f\x00\xaa\xdf\x1f\x13\x44\x65legationResponses\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xa2\x01\n)QueryValidatorUnbondingDelegationsRequest\x12\x39\n\x0evalidator_addr\x18\x01 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest\"\xbe\x01\n*QueryValidatorUnbondingDelegationsResponse\x12S\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x8f\x01\n\x16QueryDelegationRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x39\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x17QueryDelegationResponse\x12G\n\x13\x64\x65legation_response\x18\x01 \x01(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponse\"\x98\x01\n\x1fQueryUnbondingDelegationRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x39\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"j\n QueryUnbondingDelegationResponse\x12\x46\n\x06unbond\x18\x01 \x01(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x9a\x01\n QueryDelegatorDelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb5\x01\n!QueryDelegatorDelegationsResponse\x12S\n\x14\x64\x65legation_responses\x18\x01 \x03(\x0b\x32*.cosmos.staking.v1beta1.DelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xa3\x01\n)QueryDelegatorUnbondingDelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xbe\x01\n*QueryDelegatorUnbondingDelegationsResponse\x12S\n\x13unbonding_responses\x18\x01 \x03(\x0b\x32+.cosmos.staking.v1beta1.UnbondingDelegationB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\xff\x01\n\x19QueryRedelegationsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x12src_validator_addr\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x34\n\x12\x64st_validator_addr\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x04 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xb2\x01\n\x1aQueryRedelegationsResponse\x12W\n\x16redelegation_responses\x18\x01 \x03(\x0b\x32,.cosmos.staking.v1beta1.RedelegationResponseB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x99\x01\n\x1fQueryDelegatorValidatorsRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequest:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\xa1\x01\n QueryDelegatorValidatorsResponse\x12@\n\nvalidators\x18\x01 \x03(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12;\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponse\"\x97\x01\n\x1eQueryDelegatorValidatorRequest\x12\x30\n\x0e\x64\x65legator_addr\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x39\n\x0evalidator_addr\x18\x02 \x01(\tB!\xd2\xb4-\x1d\x63osmos.ValidatorAddressString:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"b\n\x1fQueryDelegatorValidatorResponse\x12?\n\tvalidator\x18\x01 \x01(\x0b\x32!.cosmos.staking.v1beta1.ValidatorB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\",\n\x1aQueryHistoricalInfoRequest\x12\x0e\n\x06height\x18\x01 \x01(\x03\"S\n\x1bQueryHistoricalInfoResponse\x12\x34\n\x04hist\x18\x01 \x01(\x0b\x32&.cosmos.staking.v1beta1.HistoricalInfo\"\x12\n\x10QueryPoolRequest\"J\n\x11QueryPoolResponse\x12\x35\n\x04pool\x18\x01 \x01(\x0b\x32\x1c.cosmos.staking.v1beta1.PoolB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\"\x14\n\x12QueryParamsRequest\"P\n\x13QueryParamsResponse\x12\x39\n\x06params\x18\x01 \x01(\x0b\x32\x1e.cosmos.staking.v1beta1.ParamsB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x32\xb0\x16\n\x05Query\x12\x9e\x01\n\nValidators\x12..cosmos.staking.v1beta1.QueryValidatorsRequest\x1a/.cosmos.staking.v1beta1.QueryValidatorsResponse\"/\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02$\x12\"/cosmos/staking/v1beta1/validators\x12\xac\x01\n\tValidator\x12-.cosmos.staking.v1beta1.QueryValidatorRequest\x1a..cosmos.staking.v1beta1.QueryValidatorResponse\"@\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x35\x12\x33/cosmos/staking/v1beta1/validators/{validator_addr}\x12\xd9\x01\n\x14ValidatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryValidatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryValidatorDelegationsResponse\"L\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x41\x12?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations\x12\xfe\x01\n\x1dValidatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryValidatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations\x12\xcc\x01\n\nDelegation\x12..cosmos.staking.v1beta1.QueryDelegationRequest\x1a/.cosmos.staking.v1beta1.QueryDelegationResponse\"]\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02R\x12P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}\x12\xfc\x01\n\x13UnbondingDelegation\x12\x37.cosmos.staking.v1beta1.QueryUnbondingDelegationRequest\x1a\x38.cosmos.staking.v1beta1.QueryUnbondingDelegationResponse\"r\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02g\x12\x65/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation\x12\xce\x01\n\x14\x44\x65legatorDelegations\x12\x38.cosmos.staking.v1beta1.QueryDelegatorDelegationsRequest\x1a\x39.cosmos.staking.v1beta1.QueryDelegatorDelegationsResponse\"A\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x36\x12\x34/cosmos/staking/v1beta1/delegations/{delegator_addr}\x12\xfe\x01\n\x1d\x44\x65legatorUnbondingDelegations\x12\x41.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsRequest\x1a\x42.cosmos.staking.v1beta1.QueryDelegatorUnbondingDelegationsResponse\"V\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02K\x12I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations\x12\xc6\x01\n\rRedelegations\x12\x31.cosmos.staking.v1beta1.QueryRedelegationsRequest\x1a\x32.cosmos.staking.v1beta1.QueryRedelegationsResponse\"N\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x43\x12\x41/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations\x12\xd5\x01\n\x13\x44\x65legatorValidators\x12\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorsRequest\x1a\x38.cosmos.staking.v1beta1.QueryDelegatorValidatorsResponse\"K\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators\x12\xe3\x01\n\x12\x44\x65legatorValidator\x12\x36.cosmos.staking.v1beta1.QueryDelegatorValidatorRequest\x1a\x37.cosmos.staking.v1beta1.QueryDelegatorValidatorResponse\"\\\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02Q\x12O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}\x12\xb8\x01\n\x0eHistoricalInfo\x12\x32.cosmos.staking.v1beta1.QueryHistoricalInfoRequest\x1a\x33.cosmos.staking.v1beta1.QueryHistoricalInfoResponse\"=\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x32\x12\x30/cosmos/staking/v1beta1/historical_info/{height}\x12\x86\x01\n\x04Pool\x12(.cosmos.staking.v1beta1.QueryPoolRequest\x1a).cosmos.staking.v1beta1.QueryPoolResponse\")\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02\x1e\x12\x1c/cosmos/staking/v1beta1/pool\x12\x8e\x01\n\x06Params\x12*.cosmos.staking.v1beta1.QueryParamsRequest\x1a+.cosmos.staking.v1beta1.QueryParamsResponse\"+\x88\xe7\xb0*\x01\x82\xd3\xe4\x93\x02 \x12\x1e/cosmos/staking/v1beta1/paramsB.Z,github.com/cosmos/cosmos-sdk/x/staking/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.staking.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z,github.com/cosmos/cosmos-sdk/x/staking/types'
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYVALIDATORREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\252\337\037\023DelegationResponses\250\347\260*\001'
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._loaded_options = None
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE'].fields_by_name['unbond']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._loaded_options = None
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE'].fields_by_name['delegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._loaded_options = None
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE'].fields_by_name['unbonding_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['src_validator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['src_validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['dst_validator_addr']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST'].fields_by_name['dst_validator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYREDELEGATIONSREQUEST']._loaded_options = None
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._loaded_options = None
  _globals['_QUERYREDELEGATIONSRESPONSE'].fields_by_name['redelegation_responses']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE'].fields_by_name['validators']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['delegator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['delegator_addr']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['validator_addr']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST'].fields_by_name['validator_addr']._serialized_options = b'\322\264-\035cosmos.ValidatorAddressString'
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._loaded_options = None
  _globals['_QUERYDELEGATORVALIDATORRESPONSE'].fields_by_name['validator']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._loaded_options = None
  _globals['_QUERYPOOLRESPONSE'].fields_by_name['pool']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Validators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002$\022\"/cosmos/staking/v1beta1/validators'
  _globals['_QUERY'].methods_by_name['Validator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Validator']._serialized_options = b'\210\347\260*\001\202\323\344\223\0025\0223/cosmos/staking/v1beta1/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002A\022?/cosmos/staking/v1beta1/validators/{validator_addr}/delegations'
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/validators/{validator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Delegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Delegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002R\022P/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UnbondingDelegation']._serialized_options = b'\210\347\260*\001\202\323\344\223\002g\022e/cosmos/staking/v1beta1/validators/{validator_addr}/delegations/{delegator_addr}/unbonding_delegation'
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\0026\0224/cosmos/staking/v1beta1/delegations/{delegator_addr}'
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorUnbondingDelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002K\022I/cosmos/staking/v1beta1/delegators/{delegator_addr}/unbonding_delegations'
  _globals['_QUERY'].methods_by_name['Redelegations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Redelegations']._serialized_options = b'\210\347\260*\001\202\323\344\223\002C\022A/cosmos/staking/v1beta1/delegators/{delegator_addr}/redelegations'
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidators']._serialized_options = b'\210\347\260*\001\202\323\344\223\002@\022>/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators'
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._loaded_options = None
  _globals['_QUERY'].methods_by_name['DelegatorValidator']._serialized_options = b'\210\347\260*\001\202\323\344\223\002Q\022O/cosmos/staking/v1beta1/delegators/{delegator_addr}/validators/{validator_addr}'
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._loaded_options = None
  _globals['_QUERY'].methods_by_name['HistoricalInfo']._serialized_options = b'\210\347\260*\001\202\323\344\223\0022\0220/cosmos/staking/v1beta1/historical_info/{height}'
  _globals['_QUERY'].methods_by_name['Pool']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Pool']._serialized_options = b'\210\347\260*\001\202\323\344\223\002\036\022\034/cosmos/staking/v1beta1/pool'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\210\347\260*\001\202\323\344\223\002 \022\036/cosmos/staking/v1beta1/params'
  _globals['_QUERYVALIDATORSREQUEST']._serialized_start=271
  _globals['_QUERYVALIDATORSREQUEST']._serialized_end=371
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_start=374
  _globals['_QUERYVALIDATORSRESPONSE']._serialized_end=526
  _globals['_QUERYVALIDATORREQUEST']._serialized_start=528
  _globals['_QUERYVALIDATORREQUEST']._serialized_end=610
  _globals['_QUERYVALIDATORRESPONSE']._serialized_start=612
  _globals['_QUERYVALIDATORRESPONSE']._serialized_end=701
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_start=704
  _globals['_QUERYVALIDATORDELEGATIONSREQUEST']._serialized_end=857
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_start=860
  _globals['_QUERYVALIDATORDELEGATIONSRESPONSE']._serialized_end=1064
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=1067
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=1229
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=1232
  _globals['_QUERYVALIDATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=1422
  _globals['_QUERYDELEGATIONREQUEST']._serialized_start=1425
  _globals['_QUERYDELEGATIONREQUEST']._serialized_end=1568
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_start=1570
  _globals['_QUERYDELEGATIONRESPONSE']._serialized_end=1668
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_start=1671
  _globals['_QUERYUNBONDINGDELEGATIONREQUEST']._serialized_end=1823
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_start=1825
  _globals['_QUERYUNBONDINGDELEGATIONRESPONSE']._serialized_end=1931
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_start=1934
  _globals['_QUERYDELEGATORDELEGATIONSREQUEST']._serialized_end=2088
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_start=2091
  _globals['_QUERYDELEGATORDELEGATIONSRESPONSE']._serialized_end=2272
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_start=2275
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSREQUEST']._serialized_end=2438
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_start=2441
  _globals['_QUERYDELEGATORUNBONDINGDELEGATIONSRESPONSE']._serialized_end=2631
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_start=2634
  _globals['_QUERYREDELEGATIONSREQUEST']._serialized_end=2889
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_start=2892
  _globals['_QUERYREDELEGATIONSRESPONSE']._serialized_end=3070
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_start=3073
  _globals['_QUERYDELEGATORVALIDATORSREQUEST']._serialized_end=3226
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_start=3229
  _globals['_QUERYDELEGATORVALIDATORSRESPONSE']._serialized_end=3390
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_start=3393
  _globals['_QUERYDELEGATORVALIDATORREQUEST']._serialized_end=3544
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_start=3546
  _globals['_QUERYDELEGATORVALIDATORRESPONSE']._serialized_end=3644
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_start=3646
  _globals['_QUERYHISTORICALINFOREQUEST']._serialized_end=3690
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_start=3692
  _globals['_QUERYHISTORICALINFORESPONSE']._serialized_end=3775
  _globals['_QUERYPOOLREQUEST']._serialized_start=3777
  _globals['_QUERYPOOLREQUEST']._serialized_end=3795
  _globals['_QUERYPOOLRESPONSE']._serialized_start=3797
  _globals['_QUERYPOOLRESPONSE']._serialized_end=3871
  _globals['_QUERYPARAMSREQUEST']._serialized_start=3873
  _globals['_QUERYPARAMSREQUEST']._serialized_end=3893
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=3895
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=3975
  _globals['_QUERY']._serialized_start=3978
  _globals['_QUERY']._serialized_end=6842
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cosmos/msg/textual/v1/textual.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'cosmos/msg/textual/v1/textual.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#cosmos/msg/textual/v1/textual.proto\x12\x15\x63osmos.msg.textual.v1\x1a google/protobuf/descriptor.proto:B\n\x16\x65xpert_custom_renderer\x12\x1f.google.protobuf.MessageOptions\x18\xf9\x8c\xa6\x05 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.msg.textual.v1.textual_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
# @@protoc_insertion_point(module_scope)
